/* ------------------------------------------------------------------------- *
 * An example SAS program for Stats 506.
 *
 * This file imports RECS data from:
 *   recs2020_public_v5.csv
 *   http://www.eia.gov/consumption/residential/data/2020/
 *        index.cfm?view=microdata
 *
 * Then prints some basic information about the file.
 *
 * Author: James Henderson 
 * Updated: Oct 9, 2023
 * ------------------------------------------------------------------------- *
*/

/* 79: --------------------------------------------------------------------- */

/* input and output paths: ------------------------------------------------- */
%let in_path = ~/my_shared_file_links/jbhender0/input_data/;
run;

/* import delimited data in a data step: ----------------------------------- */

data test;
 infile "&in_path.test_file.csv" dsd dlmstr=',' firstobs=2 truncover;
 input v1 :$5. v2 :$3. v3 :$3.;
run;

proc print data=test;
proc contents data=test;
run;

/* import delimited data with proc import: --------------------------------- */
proc import datafile="&in_path.recs2020_public_v5.csv" out=recs;

/* print the first 5 rows for a few variales: ------------------------------ */
proc print data=recs(obs=5);      /* (obs=5) is an 'option' */
    var DOEID NWEIGHT REGIONC;    /* This is a 'statement'  */

/* get some basic information about the imported data: --------------------- */
proc contents data=recs;

run;

/* 79: --------------------------------------------------------------------- */
