/* ------------------------------------------------------------------------- *
 * An example SAS program for Stats 506.
 *
 *
 * Create urban and rural subsets of the 2020 RECS data and writes as sas7bdat.
 *
 * Author: James Henderson
 * Updated: Oct 9, 2023
 * ------------------------------------------------------------------------- *
*/
/* 79: --------------------------------------------------------------------- */

/* data library for reading/writing data: ---------------------------------- */
%let in_path = ~/my_shared_file_links/jbhender0/input_data;
%let out_path = ~/my_shared_file_links/jbhender0/output_data; 
libname in_lib "&in_path."; 
libname out_lib "&out_path.";

/* Create a rural subset: -------------------------------------------------- */
data rural;
 set in_lib.recs2020_public_v5;
  if ur='U' then delete;

data out_lib.recs_rural;
  set rural;
run;

/* Create and write an urban subset: --------------------------------------- */
data urban;
 set in_lib.recs2020_public_v5;
  /*if ur='R' then delete;*/
  where ur='U'; 
  
data out_lib.recs_urban;
 set urban;
run;

/* Compare final obs between CSV and sas7bdat: ----------------------------- */
data saslast5;
  set in_lib.recs2020_public_v5 nobs=obscount;
  if _n_ gt (obscount - 5); 
  keep DOEID;
  rename DOEID = sas_id; 
run; 

proc print data=saslast5;

data csvlast5; 
 set out_lib.recs2020 nobs=obscount;
 if _n_ gt (obscount - 5);
 keep DOEID;
 rename DOEID = csv_id;

proc print data=csvlast5;

/* 79: --------------------------------------------------------------------- */
