/* ------------------------------------------------------------------------- *
 * An example SAS program for Stats 506.
 *
 * Pivoting data between wider and longer formats
 * 
 * Author: James Henderson
 * Updated: Oct 11, 2023
 * ------------------------------------------------------------------------- *
*/
/* 79: --------------------------------------------------------------------- */

/* data library for reading/writing data: ---------------------------------- */
%let in_path = ~/my_shared_file_links/jbhender0/input_data;
%let out_path = ~/my_shared_file_links/jbhender0/output_data; 
libname in_lib "&in_path."; 
libname out_lib "&out_path.";

/* create long format replicate weights: ----------------------------------- */
proc transpose 
  data=in_lib.recs2020_public_v5
  out=out_lib.w2020_long
  prefix=nweight;
 by doeid;
 var nweight1-nweight60; 
run;  

data out_lib.w2020_long;
  set out_lib.w2020_long; 
  drop _LABEL_; 
  rename _NAME_ = replicate;
  rename nweight1 = w_r;
run; 

data out_lib.w2020_long;
  set out_lib.w2020_long; 
  w_sq_r = w_r * w_r; 
run; 

/* pivot back to wide as a demonstration: ---------------------------------- */
/* already in order, but if not sort ascending */
/* 
proc sort
  data=out_lib.w2020_long
  ascending doeid replicate; 
*/
  
proc transpose 
  data=out_lib.w2020_long
  out=out_lib.w2020_wide;
  by doeid;
  id replicate; 
  var w_r;
run; 

/* 79: --------------------------------------------------------------------- */
