/* ------------------------------------------------------------------------- *
 * An example SAS program for Stats 506.
 *
 * Using proc summary to compute effective sample sizes for each 
 * Census Region. 
 * 
 * Author: James Henderson
 * Updated: Oct 11, 2023
 * ------------------------------------------------------------------------- *
*/
/* 79: --------------------------------------------------------------------- */

/* data library for reading/writing data: ---------------------------------- */
%let in_path = ~/my_shared_file_links/jbhender0/input_data;
%let out_path = ~/my_shared_file_links/jbhender0/output_data; 
libname in_lib "&in_path."; 
libname out_lib "&out_path.";

/* effective sample size for each census region: --------------------------- */

/* sort data by region */
proc sort
  data=in_lib.recs2020_public_v5
  out=recs2020; 
  by regionc; 
run; 

data recs2020;
  set recs2020;
  nweight_sq = nweight * nweight;
run; 

proc summary data=recs2020;
  class regionc; 
  output out=ess_by_region_recs2020
    sum(nweight) = num
    sum(nweight_sq) = den;
run; 

data out_lib.ess_by_region_recs2020; 
  set ess_by_region_recs2020;
  where _type_ = 1; 
  ess = num * num / den; 
  drop num den _type_;
run;

/* 79: --------------------------------------------------------------------- */
