/* ------------------------------------------------------------------------- *
 * An example SAS program for Stats 506.
 *
 * Demonstration of data merging. 
 *
 * Use replicate weights and proc summary to compute replicate estimates
 * of the effective sample sizes. 
 *
 * Then compute a Jackknife variance estimate using the replicate weights. 
 * 
 * Author: James Henderson
 * Updated: Oct 11, 2023
 * ------------------------------------------------------------------------- *
*/
/* 79: --------------------------------------------------------------------- */

/* data library for reading/writing data: ---------------------------------- */
%let in_path = ~/my_shared_file_links/jbhender0/input_data;
%let out_path = ~/my_shared_file_links/jbhender0/output_data; 
libname in_lib "&in_path."; 
libname out_lib "&out_path.";

/* merge census region into a copy of the long format replicate weights: --- */
data w_long;
  merge
    out_lib.w2020_long(keep=doeid replicate w_r)
    in_lib.recs2020_public_v5(keep=doeid regionc);
  by doeid;
run; 

/* effective replicate ess for each census region: ------------------------- */
proc sort w_long;
  set w_long;
  by regionc replicate;
run; 

data w_long;
  set w_long;
  w_sq_r = w_r * w_r; 
run; 

proc summary data=w_long;
  class regionc replicate;
  output out=ess_repl
    sum(w_r) = num
    sum(w_sq_r) = den
; 

data ess_repl;
  set ess_repl;
  where _type_ = 3;
  ess_r = num * num / den;
  keep regionc replicate ess_r;
run;
    
/* jackknife variance estimate for the ess using replicate weights: ------- */

/* merge the point estimate and replicate estimates together */
data ess_repl; 
  merge ess_repl out_lib.ess_by_region_recs2020;
  by regionc;
run; 

data ess_repl; 
  set ess_repl;
  res_sq = (ess - ess_r)**2;   
run; 


/* sum of squared deviations */
proc summary data=ess_repl; 
  class regionc; 
  output out=ess_v
    sum(res_sq) = rss;
run; 

/* variance estimate */
data ess_v;
  set ess_v;
  v = (_freq_ - 1) / (_freq_) * rss;
  where _type_ = 1; 
run;

/* standard error and confidence intervals */
%let z = 1.96;

data ess_v;
  merge ess_v out_lib.ess_by_region_recs2020(keep=regionc ess); 
  by regionc;
  se = sqrt(v); 
run;

data ess_v;
  set ess_v;
  lwr = ess - &z. * se;
  upr = ess + &z. * se;
run;
  